==> packetvisualization-0.0.6.tar.gz: packetvisualization-0.0.6/packetvisualization/models/pcap.py <==
import os
import shutil
import pyshark

class Pcap:

    def __init__(self, name: str ,path: str, file: str, m_data = "") -> None:
        try:
            self.name = name
            self.path = os.path.join(path, self.name)  # Save location for PCAP File
            self.pcap_file = file  # pcap recieved from user
            self.pcap_data = None  # packet capture object (packets within pcap file)
            self.total_packets = 0
            self.protocols = {}
            self.m_data = m_data   # metadata will go to packet

            self.set_packet_data()
            #self.calculate_total_packets()
            if not self.pcap_file == self.path:
                shutil.copy(self.pcap_file, self.path)  # Copy user input into our directory
        except:
            print("Error adding this pcap")
            self.name = None

    def set_packet_data(self): # Don't need
        self.pcap_data = pyshark.FileCapture(self.pcap_file)
        return self.pcap_data

    def calculate_total_packets(self) -> int:
        count =[]

        def counter(*args):
            count.append(args[0])

        self.pcap_data.apply_on_packets(counter)
        self.total_packets = len(count)
        return len(count)

    #return lists
    #TODO:
    def calculate_protocols(self) -> dict:
        print("create dictionary from base file, traverse packets and create dictionary based on protocol/occurances")

    #TODO:
    def calculate_timespan(self) -> str:
        print("get last packet time, set as timespan")
        # knows original PCAP names
    #TODO:
    def get_pcap_name(self) -> str:
        print("# knows where PCAP originated from")

        # knows PCAP editable free text meta-data
    
    def save(self, f) -> None: # TODO: Rework
        f.write('{"name": "%s", "m_data": "%s"' % (self.name, self.m_data))
        f.write('}')

    def remove(self) -> bool: # Moved to entity operator
        return self.__del__()

    def __del__(self) -> bool:
        try:
            shutil.rmtree(self.path)
            return True
        except:
            return False

==> packetvisualization-0.0.10.tar.gz: packetvisualization-0.0.10/packetvisualization/models/pcap.py <==
import os
import shutil

class Pcap:
    def __init__(self, name: str ,path: str, file: str, m_data = "") -> None:
        try:
            self.name = name
            self.directory = path
            self.path = os.path.join(path, self.name)  # Save location for PCAP File
            self.pcap_file = file  # pcap recieved from user
            self.total_packets = 0
            self.protocols = {}
            self.m_data = m_data   # metadata will go to packet
            self.json_file = None

            if not self.pcap_file == self.path:
                shutil.copy(self.pcap_file, self.path)  # Copy user input into our directory

            self.create_json_file() # create empty json
            self.toJson()
        except:
            print("Error adding this pcap")
            self.name = None

    def create_json_file(self):
        filename = self.name + ".json"
        path = os.path.join(self.directory, filename)
        self.json_file= path
        fp = open(path, 'a')
        fp.close()

    def toJson(self):
        os.system('cd "C:\Program Files\Wireshark" & tshark -r ' + self.pcap_file + ' -T json > ' + self.json_file)

    def clearJson(self):
        print("Test")
        # Remove json file after DB insert

    def save(self, f) -> None: # TODO: Rework
        f.write('{"name": "%s", "m_data": "%s"' % (self.name, self.m_data))
        f.write('}')

    def remove(self) -> bool: # Moved to entity operator
        return self.__del__()

    def __del__(self) -> bool:
        try:
            shutil.rmtree(self.path)
            return True
        except:
            return False
